@@ -15,7 +15,7 @@ use strict;
 BEGIN {
         use Exporter ();
         use vars qw($VERSION @ISA @EXPORT);
-        $VERSION = "1.12";
+        $VERSION = "1.4";
         @ISA = qw(Exporter);
         @EXPORT = qw(
 		     &getHandlers
@@ -42,10 +42,6 @@ sub getHandlers
 		    "php"	=> 'Autodia::Handler::PHP',
 		    "dbi"       => 'Autodia::Handler::DBI',
 		    "dia"       => 'Autodia::Handler::dia',
-		    "sql"       => 'Autodia::Handler::SQL',
-		    "torque"    => 'Autodia::Handler::Torque',
-		    "python"    => 'Autodia::Handler::python',
-		    "umbrello"  => 'Autodia::Handler::umbrello',
 		   );
     print "getting handlers..\n" unless ( $config{silent} );
     return \%handlers;
@@ -71,37 +67,19 @@ sub getPattern
 	     );
 
   my %cpp  = (
-	      regex     => '\w+\.(c|cpp|hh?)$',
+	      regex     => '\w+\.[c|cpp|h]$',
 	      wildcards => [
-			    "c", "cpp", "h","hh"
+			    "c", "cpp", "h",
 			   ],
 	     );
 
    my %java = (
-	       regex     => '\w+\.(java|class)$',
+	       regex     => '\w+\.[java|class]$',
 	       wildcards => [
 			      "java", "class",
 			    ],
 	      );
 
-  my %python = (
-		regex    => '\w+.py$',
-		wildcards => [ 'py', ]
-		);
-
- my %dia    = ( regex   => '\w+.dia',
-		 wildcards => ['dia'],
-		);
-
- my %sql    = ( regex   => '\w+.sql',
-                 wildcards => ['sql'],
-                );
-
-
-  my %umbrello = ( regex => '\w+.xmi',
-		   wildcards =>  ['xmi'],
-		);
-
   my %patterns = (
 		  "perl" => \%perl,
 		  'c++'  => \%cpp,
@@ -109,11 +87,6 @@ sub getPattern
 		  "java" => \%java,
 		  "php"  => \%php,
 		  "dbi"  => {},
-		  "dia"  => \%dia,
-		  "sql"  => \%sql,
-		  "torque" => {},
-		  "python" => \%python,
-		  "umbrello" => \%umbrello,
 		 );
 
   return \%{$patterns{$language}};
