@@ -81,21 +81,20 @@ sub _parse
 	      $self->{in_class} = 1;
 	      $self->{privacy} = "private";
 	      $self->{visibility} = 1;
-	      $classname =~ s/[\{\}]//g;
 	      $Class = Autodia::Diagram::Class->new($classname);
 	      $Diagram->add_class($Class);
 
 	      # handle superclass(es)
-	      if ($line =~ m/^\s*class\s+\w+\s*\:\s*(.+)\s*/)
+	      if ($line =~ m/^\s*class\s+\w+\s*\:(.+)/)
 		{
 		  my $superclasses = $1;
-		  warn "found superclasses : $superclasses\n";
-		  my @superclasses = split (/\s*,\s*/, $superclasses);
+		  chomp $superclasses;
+#		  print "found superclasses : $superclasses\n";
+		  my @superclasses = split (",", $superclasses);
 		  foreach my $super (@superclasses)
 		    {
-		      warn "superclass : $super\n";
-		      $super =~ s/^\s*\w+\s+([A-Za-z0-9\_]+)\s*$/$1/;
-		      warn "superclass : $super\n";
+		      chomp $super;
+		      $super =~ s/^\s*\w+\s+([A-Za-z0-9\_]+)$/$1/;
 		      my $Superclass = Autodia::Diagram::Superclass->new($super);
 		      my $exists_already = $Diagram->add_superclass($Superclass);
 		      if (ref $exists_already)
@@ -266,12 +265,12 @@ sub _parse
 		  while ($have_continuation)
 		    {
 		      my $line = <$fh>;
-		      last unless ($line);
 		      chomp $line;
+#		      print "line $i (cont) : $line \n";
 
 		      if ($line =~ m/^                        # start of line
                                      \s*                      # whitespace
-			             ([\w\,\|\s\*=&\"]*)      # all parameters: $1
+                                     ([\w\,\s\*=&\"]*)        # all parameters: $1
                                      (\)?)                    # may be an ending bracket: $2
                                      [\w\s=]*(;?)             # possibly end of signature $3
                                      .*$/x)
@@ -459,13 +458,6 @@ sub _discard_line
 	    last SWITCH;
 	}
 
-	 # if line is a comment discard
-        if ($line =~ m!^\s*/\*.*\*/!)
-        {
-            $discard = 1;
-            last SWITCH;
-        }
-
 	# if line starts with multiline comment syntax discard and set flag
 	if ($line =~ /^\s*\/\*/)
 	{
