@@ -41,8 +41,6 @@ sub _parse {
   my $filename = shift;
   my $Diagram  = $self->{Diagram};
 
-  my $pkg_regexp = qr([\w:]+);
-
   my $Class;
 
   $self->{pod} = 0;
@@ -55,21 +53,21 @@ sub _parse {
     }
 
     # if line contains package name then parse for class name
-    if ($line =~ /^\s*package\s+($pkg_regexp)/) {
+    if ($line =~ /^\s*package\s+([A-Za-z0-9\:]+)/) {
       my $className = $1;
       # create new class with name
       $Class = Autodia::Diagram::Class->new($className);
       # add class to diagram
-      $Class = $Diagram->add_class($Class);
+      $Diagram->add_class($Class);
     }
 
-    if ($line =~ /^\s*use\s+base\s+(?:q|qw){0,1}\s*([\(\{\/\#])\s*(.*)\s*[\)\}\1]/) {
-      my $superclass = $2;
+    if ($line =~ /^\s*use\s+base\s+(?:q|qw){0,1}\((.*)\)/) {
+      my $superclass = $1;
 
       # check package exists before doing stuff
       $self->_is_package(\$Class, $filename);
 
-      my @superclasses = split(/[\s*,]/, $superclass);
+      my @superclasses = split(" ", $superclass);
 
       foreach my $super (@superclasses) # WHILE_SUPERCLASSES
 	{
@@ -80,7 +78,6 @@ sub _parse {
 	  # add superclass to diagram
 
 	  my $exists_already = $Diagram->add_superclass($Superclass);
-#	  warn "already exists ? $exists_already \n";
 	  if (ref $exists_already) {
 	    $Superclass = $exists_already;
 	  }
@@ -97,23 +94,22 @@ sub _parse {
     }
 
     # if line contains dependancy name then parse for module name
-    if ($line =~ /^\s*(use|require)\s+($pkg_regexp)/) {
+    if ($line =~ /^\s*(use|require)\s+([A-Za-z0-9\:]+)/) {
       my $componentName = $2;
 
       # discard if stopword
-      next if ($componentName =~ /^(strict|vars|exporter|autoloader|warnings.*|constant.*|data::dumper|carp.*|overload|switch|\d|lib)$/i);
+      next if ($componentName =~ /^(strict|vars|exporter|autoloader|warnings.*|constant.*|data::dumper|\d|lib)$/i);
 
       # check package exists before doing stuff
       $self->_is_package(\$Class, $filename);
 
+      if ($componentName eq 'fields') {
 
-      if ($componentName =~ /(fields|private|public)/) {
-	my $pragma = $1;
 	$line =~ /\sqw\((.*)\)/;
 	my @fields = split(/\s+/,$1);
 	foreach my $field (@fields) {
 	  my $attribute_visibility = ( $field =~ m/^\_/ ) ? 1 : 0;
-          unless ($pragma eq 'fields') { $attribute_visibility = ($pragma eq 'private' ) ? 1 : 0; }
+
 	  $Class->add_attribute({
 				 name => $field,
 				 visibility => $attribute_visibility,
@@ -144,39 +140,33 @@ sub _parse {
     # if ISA in line then extract templates/superclasses
     if ($line =~ /^\s*\@(?:\w+\:\:)*ISA\s*\=\s*(?:q|qw){0,1}\((.*)\)/) {
       my $superclass = $1;
-      
-#      warn "handling superclasses $1 with \@ISA\n";
-#      warn "superclass line : $line \n";
-      if ($superclass) {
-	  # check package exists before doing stuff
-	  $self->_is_package(\$Class, $filename);
 
-	  my @superclasses = split(" ", $superclass);
+      # check package exists before doing stuff
+      $self->_is_package(\$Class, $filename);
 
-	  foreach my $super (@superclasses) # WHILE_SUPERCLASSES
-	  {
-	      # discard if stopword
-	      next if ($super =~ /(?:exporter|autoloader)/i || !$super);
-	      # create superclass
-	      my $Superclass = Autodia::Diagram::Superclass->new($super);
-	      # add superclass to diagram
-	      my $exists_already = $Diagram->add_superclass($Superclass);
-#	      warn "already exists ? $exists_already \n";
-	      if (ref $exists_already) {
-		  $Superclass = $exists_already;
-	      }
-	      # create new inheritance
-#	      warn "creating inheritance from superclass : $super\n";
-	      my $Inheritance = Autodia::Diagram::Inheritance->new($Class, $Superclass);
-	      # add inheritance to superclass
-	      $Superclass->add_inheritance($Inheritance);
-	      # add inheritance to class
-	      $Class->add_inheritance($Inheritance);
-	      # add inheritance to diagram
-	      $Diagram->add_inheritance($Inheritance);
+      my @superclasses = split(" ", $superclass);
+
+      foreach my $super (@superclasses) # WHILE_SUPERCLASSES
+	{
+	  # discard if stopword
+	  next if ($super =~ /(?:exporter|autoloader)/i);
+	  # create superclass
+	  my $Superclass = Autodia::Diagram::Superclass->new($super);
+	  # add superclass to diagram
+	  my $exists_already = $Diagram->add_superclass($Superclass);
+	  if (ref $exists_already) {
+	    $Superclass = $exists_already;
 	  }
-      } else { warn "ignoring empty \@ISA \n"; }
-  }
+	  # create new inheritance
+	  my $Inheritance = Autodia::Diagram::Inheritance->new($Class, $Superclass);
+	  # add inheritance to superclass
+	  $Superclass->add_inheritance($Inheritance);
+	  # add inheritance to class
+	  $Class->add_inheritance($Inheritance);
+	  # add inheritance to diagram
+	  $Diagram->add_inheritance($Inheritance);
+	}
+    }
 
     # if line contains sub then parse for method data
     if ($line =~ /^\s*sub\s+?(\w+)/) {
@@ -196,8 +186,8 @@ sub _parse {
     }
 
     # if line contains object attributes parse add to class
-    if ($line =~ m/\$(class|self|this)\-\>\{['"]*(.*?)["']*}/) {
-      my $attribute_name = $2;
+    if ($line =~ m/[(\$class|\$self|\$this|shift\(?\)?)]\-\>\{\"*(.*?)\"*}/) {
+      my $attribute_name = $1;
       my $attribute_visibility = ( $attribute_name =~ m/^\_/ ) ? 1 : 0;
 
       $Class->add_attribute({
