@@ -16,11 +16,14 @@ use File::Find;
 
 use Autodia;
 
+
 # get configuration from command line
 my %args=();
-getopts("FCsSDOmMaArhHi:o:p:d:t:l:zZvVU:P:",\%args);
+getopts("sSDOmrhi:o:p:d:t:l:zZvVU:P:",\%args);
 my %config = %{get_config(\@ARGV,\%args)};
 
+
+
 print "\n\nAutoDia - version ".$Autodia::VERSION."(c) Copyright 2003 A Trevena\n\n" unless ( $config{silent} );
 
 # create new diagram
@@ -35,7 +38,7 @@ print "using language : ", $config{language}, "\n" unless ( $config{silent} );
 if (defined $language_handlers{lc($config{language})})
   {
     my $handler_module = $language_handlers{lc($config{language})};
-    eval "require $handler_module" or die "can't run $handler_module : $! : $@\n";
+    eval "require $handler_module" or die "can't find $handler_module : $!\n";
     print "\n..using $handler_module\n" unless ( $config{silent} );
     $handler = "$handler_module"->new(\%config);
   }
@@ -50,29 +53,31 @@ else
 
 $handler->process();
 
-$handler->output() unless ($config{singlefile});
+$handler->output();
 
 print "complete. (processed ", scalar(@{$config{filenames}}), " files)\n\n" unless ( $config{silent} );
 
 ####################################################################
 
-sub get_config {
+sub get_config
+  {
     my @ARGV = @{shift()};
     my %args = %{shift()};
 
     if (defined $args{'V'}) {
-	print "\n\nAutoDia - version ".$Autodia::VERSION."(c) copyright 2003 A Trevena\n\n";
-	exit;
+      print "\n\nAutoDia - version ".$Autodia::VERSION."(c) copyright 2001 A Trevena\n\n";
+      exit;
     }
 
 
     $args{'i'} =~ s/\"// if defined $args{'i'};
     $args{'d'} =~ s/\"// if defined $args{'d'};
 
-    if ($args{'h'}) {
+    if ($args{'h'})
+      {
 	print_instructions();
 	exit;
-    }
+      }
 
     my %config = ();
     my @filenames = ();
@@ -83,112 +88,57 @@ sub get_config {
     $config{graphvizdia} = (defined $args{'Z'}) ? 1 : 0;
     $config{vcg} = (defined $args{'v'}) ? 1 : 0;
 
-    $config{singlefile} = (defined $args{'F'}) ? 1 : 0;
-    $config{skipcvs} = (defined $args{'C'}) ? 1 : 0;
-
-    $config{username} = (defined $args{'U'}) ? $args{'U'} : "root";
-    $config{password} = (defined $args{'P'}) ? $args{'P'} : "";
-
-    $config{methods}  = 1;
-    $config{attributes} = 1;
-    $config{public} = (defined $args{'H'}) ? 1 : 0;
-
-    if ( $args{'m'} || $args{'A'}) {
-	$config{attributes} = 0;
-    }
-
-    if ( $args{'M'} || $args{'a'}) {
-	$config{methods} = 0;
-    }
+    $config{username} = (defined $args{'U'}) ? $args{'l'} : "root";
+    $config{password} = (defined $args{'P'}) ? $args{'l'} : "";
 
     Autodia->setConfig(\%config);
 
     my %file_extensions = %{Autodia->getPattern()};
 
-    if (defined $args{'i'}) {
-	my $last;
-	if ($args{l} =~ /^dbi$/i) {
-	    $filenames[0] = $args{'i'};
-	    warn "have file : $filenames[0]\n";
-	} else {
-	    foreach my $filename ( split(" ",$args{'i'}) ) {
-		unless ( -f $filename ) {
-
-		    if ($last) {
-			$filename = "$last $filename";
-			unless (-f $filename) {
-			    warn "cannot find $filename .. ignoring\n";
-			    $last = $filename;
-			    next;
-			}
-		    } else {
-			$last = $filename;
-			warn "cannot find $filename .. ignoring\n";
-			next;
-		    }
-		}
-		undef $last;
-		push(@filenames,$filename);
-	    }
-	}
-    }
-    if (defined $args{'d'}) {
+    if (defined $args{'i'})
+      { @filenames = split(" ",$args{'i'}); }
+    elsif (defined $args{'d'})
+      {
 	print "using directory : " , $args{'d'}, "\n" unless ( $config{silent} );
 	my @dirs = split(" ",$args{'d'});
-	if (defined $args{'r'}) {
+	if (defined $args{'r'})
+	  {
 	    print "recursively searching files..\n" unless ( $config{silent} );
-	    find ( { wanted => sub {
-			 unless (-d) {
-			     my $regex = $file_extensions{regex};
-			     push @filenames, $File::Find::name
-				 if ($File::Find::name =~ m/$regex/);
-			 }
-		     },
-		     preprocess => sub {
-			 my @return;
-			 foreach (@_) {
-			     push(@return,$_) unless (m/^.*\/?(CVS|RCS)$/ && $config{skipcvs});
-			 }
-			 return @return;
-		     },
-		   }, @dirs );
-	} else {
+	    find ( sub
+		   {
+		     unless (-d)
+		       {
+			 my $regex = $file_extensions{regex};
+			 push @filenames, $File::Find::name
+			   if ($File::Find::name =~ m/$regex/);
+		       }
+		   } , @dirs );
+	  }
+	else
+	  {
 	    my @wildcards = @{$file_extensions{wildcards}};
 	    print "searching files using wildcards : @wildcards \n" unless ( $config{silent} );
-	    foreach my $directory (@dirs) {
-		if ($directory =~ m/^(CVS|RCS)/ and $config{skipcvs}) {
-		    warn "skipping $directory\n" unless ( $config{silent} );
-		    next;
-		}
+	    foreach my $directory (@dirs)
+	      {
 		print "searching $directory\n" unless ( $config{silent} );
 		$directory =~ s|(.*)\/$|$1|;
-		foreach my $wildcard (@wildcards) {
+		foreach my $wildcard (@wildcards)
+		  {
 		    print "$wildcard" unless ( $config{silent} );
 		    print " .. " , <$directory/*.$wildcard>, " \n";
 		    push @filenames, <$directory/*.$wildcard>;
-		}
-	    }
-	}
-    }
-    my $inputpath = "";
-    if (defined $args{'p'}) {
-	$inputpath = $args{'p'};
-	unless ($inputpath =~ m/\/$/)
-	    {
-		$inputpath .= "/";
-	    }
-    }
-    $config{inputpath} = $inputpath;
+		  }
+	      }
+	  }
+      }
+    elsif (@ARGV)
+      {	@filenames = @ARGV; }
+    else
+      {
+	print_instructions();
+	exit;
+      }
 
-
-    unless (defined $args{'d'} || $args{'i'} || $args{'p'}) {
-	if (@ARGV) {
-	    @filenames = @ARGV;
-	} else {
-	    print_instructions();
-	    exit;
-	}
-    }
     $config{filenames}    = \@filenames;
     $config{use_stdout}   = (defined $args{'O'}) ? 1 : 0;
     $config{templatefile} = (defined $args{'t'}) ? $args{'t'} : undef;
@@ -196,8 +146,18 @@ sub get_config {
     $config{no_deps}      = (defined $args{'D'}) ? 1 : 0;
     $config{sort}         = (defined $args{'s'}) ? 1 : 0;
 
+    my $inputpath = "";
+    if (defined $args{'p'})
+      {
+	$inputpath = $args{'p'};
+	unless ($inputpath =~ m/\/$/)
+	  { $inputpath .= "/"; }
+      }
+
+    $config{inputpath}    = $inputpath;
+
     return \%config;
-}
+  }
 
 sub print_instructions {
   print "AutoDia - Automatic Dia XML. Copyright 2001 A Trevena\n\n";
@@ -210,22 +170,16 @@ autodia.pl -i filename -p ..      : use ../filename as input file
 autodia.pl -d directoryname       : use *.pl/pm in directoryname as input files
 autodia.pl -d 'foo bar quz'       : use *pl/pm in directories foo, bar and quz as input files
 autodia.pl -d directory -r        : use *pl/pm in directory and its subdirectories as input files
-autodia.pl -d directory -F        : use files in directory but only one file per diagram
-autodia.pl -d directory -C        : use files in directory but skip CVS directories
 autodia.pl -o outfile.xml         : use outfile.xml as output file (otherwise uses autodial.out.xml)
 autodia.pl -O                     : output to stdout
 autodia.pl -l language            : parse source as language (ie: C) and look for appropriate filename extensions if also -d
 autodia.pl -t templatefile        : use templatefile as template (otherwise uses default)
 autodia.pl -l DBI -i "mysql:test:localhost" -U username -P password : use the test database on localhost with username and password as username and password
 autodia.pl -z                     : use graphviz to produce dot, gif, jpg or png output
+autodia.pl -Z                     : use graphviz dot coords in dia output
 autodia.pl -v                     : output VCG digraph for use with VCG
 autodia.pl -D                     : ignore dependancies (ie do not process or display dependancies)
 autodia.pl -S                     : silent mode, no output to stdout except with -O
-autodia.pl -H                     : show only public/visible methods and attributes
-autodia.pl -m                     : show only Class methods
-autodia.pl -M                     : do not show Class Methods
-autodia.pl -a                     : show only Class Attributes
-autodia.pl -A                     : do not show Class Attributes
 autodia.pl -h                     : display this help message
 autodia.pl -V                     : display copyright message and version number
 end
@@ -267,10 +221,6 @@ Helpful information, links and news can be found at the autodia website - http:/
 
 =item C<autodia.pl -d directory -r        : use *pl/pm in directory and its subdirectories as input files>
 
-=item C<autodia.pl -d directory -F        : use files in directory but only one file per diagram>
-=item C<autodia.pl -d directory -C        : use files in directory but skip CVS directories>
-
-
 =item C<autodia.pl -o outfile.xml         : use outfile.xml as output file (otherwise uses autodial.out.xml)>
 
 =item C<autodia.pl -O                     : output to stdout>
@@ -283,18 +233,10 @@ Helpful information, links and news can be found at the autodia website - http:/
 
 =item C<autodia.pl -z                     : use graphviz 'yeah, baby!'>
 
+=item C<autodia.pl -Z                     : use graphviz dot coords in dia output>
+
 =item C<autodia.pl -v                     : output VCG digraph for use with VCG>
 
-=item C<autodia.pl -H                     : show only Public/Visible methods>
-
-=item C<autodia.pl -m                     : show only Class methods>
-
-=item C<autodia.pl -M                     : do not show Class Methods>
-
-=item C<autodia.pl -a                     : show only Class Attributes>
-
-=item C<autodia.pl -A                     : do not show Class Attributes>
-
 =item C<autodia.pl -S                     : silent mode, no output to stdout except with -O>
 
 =item C<autodia.pl -h                     : display this help message>
